=============================
Python API and CLI for Nessie
=============================

Nessie is a system to provide Git like capability for Iceberg Tables/Views.

More information can be found at projectnessie.org_

.. _projectnessie.org: https://projectnessie.org
